Date: 11 3, 2001 5:23:51 PM

# System Requirements

VisualText™ runs on PCs with Windows: NT, Windows 2000, Win98, and WinME.

Analyzers built with VisualText can run stand-alone or embedded in larger applications. The runtime system has also been ported to a Redhat Linux 8.0 environment with a Gnu C++ compiler. Support for Linux and other environments that compile C++ can be arranged with Text Analysis International, Inc.

For VisualText, we recommend a machine running at 500MHz or greater, with 256MB RAM (128MB minimum), and 250MB available hard disk. Minimum requirements for monitor are 15" with a resolution of 1024x768 or better.